@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2021  Alexander König
+    Copyright (C) 1999-2022  Alexander König
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -233,7 +233,7 @@ static void gtk_tx_flash_prepare(GtkWidget* widget) {
     }
     tx_flash->channel[1].x1 = allocation.width / 2 + 2;
 
-    //tX_msg("flash: width %i: left %i, right %i", widget->allocation.width, tx_flash->channel[0].x2-tx_flash->channel[0].x1, tx_flash->channel[1].x2-tx_flash->channel[1].x1);
+    // tX_msg("flash: width %i: left %i, right %i", widget->allocation.width, tx_flash->channel[0].x2-tx_flash->channel[0].x1, tx_flash->channel[1].x2-tx_flash->channel[1].x1);
 }
 
 static void gtk_tx_flash_size_allocate(GtkWidget* widget, GtkAllocation* allocation) {
@@ -270,7 +270,7 @@ static void gtk_tx_flash_paint_yourself(GtkWidget* widget, cairo_t* cr) {
     cairo_fill(cr);
 
     cairo_set_line_width(cr, 1);
-    gdk_cairo_set_source_rgba(cr, &tx_flash->colors[COL_NORM]);
+    gdk_cairo_set_source_rgba(cr, &tx_flash->colors[COL_NORM_HALF]);
 
     x12 = DMINIX + S_MINIX;
     x21 = allocation.width - 1 - x12;
