@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2021  Alexander König
+    Copyright (C) 1999-2022  Alexander König
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -122,6 +122,11 @@ typedef enum {
     PULSE = 3
 } tX_audiodevice_type;
 
+typedef enum {
+    LINEAR = 0,
+    SINC = 1
+} tX_interpolator_type;
+
 typedef struct {
     int xinput_enable;
     char xinput_device[256];
@@ -171,13 +176,14 @@ typedef struct {
 
     char current_path[PATH_MAX];
 
-    /* new audiodevice handling 
-	   we have *all* variables for *all* audiodevice types -
-	   even if support for them is not compiled in - to keep
-	   the .terminatorX3rc.bin in sync.
-	*/
+    /* new audiodevice handling
+           we have *all* variables for *all* audiodevice types -
+           even if support for them is not compiled in - to keep
+           the .terminatorX3rc.bin in sync.
+        */
 
     tX_audiodevice_type audiodevice_type; // TX_AUDIODEVICE_TYPE_OSS etc.
+    tX_interpolator_type interpolator_type;
 
     /* OSS specific options  */
     char oss_device[PATH_MAX];
