@@ -1,6 +1,6 @@
 /*
     terminatorX - realtime audio scratching software
-    Copyright (C) 1999-2021  Alexander König
+    Copyright (C) 1999-2022  Alexander König
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ void tx_icons_init(int size) {
     tx_icons[PLAY] = "media-playback-start-symbolic";
     tx_icons[STOP] = "media-playback-stop-symbolic";
     tx_icons[RECORD] = "media-record-symbolic";
-    tx_icons[MIN_AUDIO] = "audio-x-generic-symbolic";
-    tx_icons[MIN_CONTROL] = "multimedia-volume-control-symbolic";
+    tx_icons[MIN_AUDIO] = "audio-speakers-symbolic";
+    tx_icons[MIN_CONTROL] = "audio-x-generic-symbolic";
 
     tx_icons[MINIMIZE] = "window-minimize-symbolic";
     tx_icons[MAXIMIZE] = "view-more-symbolic";
